@@ -324,6 +324,13 @@ pub enum CliCommand {
         memo: Option<String>,
         fee_payer: SignerIndex,
     },
+    CloseVoteAccount {
+        vote_account_pubkey: Pubkey,
+        destination_account_pubkey: Pubkey,
+        withdraw_authority: SignerIndex,
+        memo: Option<String>,
+        fee_payer: SignerIndex,
+    },
     VoteAuthorize {
         vote_account_pubkey: Pubkey,
         new_authorized_pubkey: Pubkey,
@@ -844,6 +851,9 @@ pub fn parse_command(
         ("withdraw-from-vote-account", Some(matches)) => {
             parse_withdraw_from_vote_account(matches, default_signer, wallet_manager)
         }
+        ("close-vote-account", Some(matches)) => {
+            parse_close_vote_account(matches, default_signer, wallet_manager)
+        }
         // Wallet Commands
         ("account", Some(matches)) => parse_account(matches, wallet_manager),
         ("address", Some(matches)) => Ok(CliCommandInfo {
@@ -1467,6 +1477,21 @@ pub fn process_command(config: &CliConfig) -> ProcessResult {
             memo.as_ref(),
             *fee_payer,
         ),
+        CliCommand::CloseVoteAccount {
+            vote_account_pubkey,
+            withdraw_authority,
+            destination_account_pubkey,
+            memo,
+            fee_payer,
+        } => process_close_vote_account(
+            &rpc_client,
+            config,
+            vote_account_pubkey,
+            *withdraw_authority,
+            destination_account_pubkey,
+            memo.as_ref(),
+            *fee_payer,
+        ),
         CliCommand::VoteAuthorize {
             vote_account_pubkey,
             new_authorized_pubkey,
@@ -1617,7 +1642,7 @@ pub fn request_and_confirm_airdrop(
     to_pubkey: &Pubkey,
     lamports: u64,
 ) -> ClientResult<Signature> {
-    let (recent_blockhash, _fee_calculator) = rpc_client.get_recent_blockhash()?;
+    let recent_blockhash = rpc_client.get_latest_blockhash()?;
     let signature =
         rpc_client.request_airdrop_with_blockhash(to_pubkey, lamports, &recent_blockhash)?;
     rpc_client.confirm_transaction_with_spinner(
